# `malbook` - A Jupyter notebooks framework for automated malware analysis

`malbook` is command line utility and a python module that helps automate 
static analysis of malware samples.

## Requirements

- python >= 3.9
- setuptools >= 52

## Installation

You can install malbook using `pip` with the following command
```powershell
python -m pip install malbook
```
on Windows, or
```sh
python3 -m pip install malbook
```
On Linux and MacOS.
